feijoa.search package
=====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   feijoa.search.algorithms

Submodules
----------

feijoa.search.bandit module
---------------------------

.. automodule:: feijoa.search.bandit
   :members:
   :undoc-members:
   :show-inheritance:

feijoa.search.meta module
-------------------------

.. automodule:: feijoa.search.meta
   :members:
   :undoc-members:
   :show-inheritance:

feijoa.search.parameters module
-------------------------------

.. automodule:: feijoa.search.parameters
   :members:
   :undoc-members:
   :show-inheritance:

feijoa.search.roundrobin module
-------------------------------

.. automodule:: feijoa.search.roundrobin
   :members:
   :undoc-members:
   :show-inheritance:

feijoa.search.seed module
-------------------------

.. automodule:: feijoa.search.seed
   :members:
   :undoc-members:
   :show-inheritance:

feijoa.search.space module
--------------------------

.. automodule:: feijoa.search.space
   :members:
   :undoc-members:
   :show-inheritance:

feijoa.search.visitors module
-----------------------------

.. automodule:: feijoa.search.visitors
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: feijoa.search
   :members:
   :undoc-members:
   :show-inheritance:
